@@ -2061,6 +2061,8 @@ enum {
     FLUX_SUBPROCESS_FLAGS_SETPGRP = 2,
 
     FLUX_SUBPROCESS_FLAGS_FORK_EXEC = 4,
+# 3539 "/__w/flux-python/flux-python/src/_core_clean.h"
+    FLUX_SUBPROCESS_FLAGS_LOCAL_UNBUF = 8,
 };
 
 
@@ -2111,7 +2113,7 @@ typedef void (*subprocess_log_f)(void *arg,
                                  int level,
                                  const char *fmt,
                                  va_list args);
-# 3601 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3612 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_subprocess_t *flux_local_exec (flux_reactor_t *r,
                                     int flags,
                                     const flux_cmd_t *cmd,
@@ -2146,7 +2148,7 @@ flux_subprocess_t *flux_rexec_ex (flux_t *h,
 
 void flux_subprocess_stream_start (flux_subprocess_t *p, const char *stream);
 void flux_subprocess_stream_stop (flux_subprocess_t *p, const char *stream);
-# 3645 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3656 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_subprocess_write (flux_subprocess_t *p,
                            const char *stream,
                            const char *buf,
@@ -2158,29 +2160,28 @@ int flux_subprocess_write (flux_subprocess_t *p,
 
 
 int flux_subprocess_close (flux_subprocess_t *p, const char *stream);
-# 3668 "/__w/flux-python/flux-python/src/_core_clean.h"
-const char *flux_subprocess_read (flux_subprocess_t *p,
-                                  const char *stream,
-                                  int len,
-                                  int *lenp);
 # 3684 "/__w/flux-python/flux-python/src/_core_clean.h"
-const char *flux_subprocess_read_line (flux_subprocess_t *p,
+int flux_subprocess_read (flux_subprocess_t *p,
+                          const char *stream,
+                          const char **bufp);
+# 3704 "/__w/flux-python/flux-python/src/_core_clean.h"
+int flux_subprocess_read_line (flux_subprocess_t *p,
+                               const char *stream,
+                               const char **bufp);
+
+
+
+
+int flux_subprocess_read_trimmed_line (flux_subprocess_t *p,
                                        const char *stream,
-                                       int *lenp);
-
-
-
-
-const char *flux_subprocess_read_trimmed_line (flux_subprocess_t *p,
-                                               const char *stream,
-                                               int *lenp);
-# 3703 "/__w/flux-python/flux-python/src/_core_clean.h"
+                                       const char **bufp);
+# 3723 "/__w/flux-python/flux-python/src/_core_clean.h"
 bool flux_subprocess_read_stream_closed (flux_subprocess_t *p,
                                          const char *stream);
-# 3722 "/__w/flux-python/flux-python/src/_core_clean.h"
-const char *flux_subprocess_getline (flux_subprocess_t *p,
-                                     const char *stream,
-                                     int *lenp);
+# 3741 "/__w/flux-python/flux-python/src/_core_clean.h"
+int flux_subprocess_getline (flux_subprocess_t *p,
+                             const char *stream,
+                             const char **bufp);
 
 
 
@@ -2266,7 +2267,7 @@ void *flux_subprocess_aux_get (flux_subprocess_t *p, const char *name);
 
 void flux_subprocess_channel_incref (flux_subprocess_t *p, const char *name);
 void flux_subprocess_channel_decref (flux_subprocess_t *p, const char *name);
-# 3825 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3844 "/__w/flux-python/flux-python/src/_core_clean.h"
 extern "Python" void message_handler_wrapper(flux_t *, flux_msg_handler_t *, const flux_msg_t *, void *);
 
 
